==> stripe-java-1.14.0-sources.jar: com/stripe/model/CustomerSubscriptionCollection.java <==
package com.stripe.model;

import java.util.Map;

import com.stripe.Stripe;
import com.stripe.exception.APIConnectionException;
import com.stripe.exception.APIException;
import com.stripe.exception.AuthenticationException;
import com.stripe.exception.CardException;
import com.stripe.exception.InvalidRequestException;

public class CustomerSubscriptionCollection extends StripeColllectionAPIResource<Subscription> {
	  public CustomerSubscriptionCollection all(Map<String, Object> params)
	      throws AuthenticationException, InvalidRequestException,
	      APIConnectionException, CardException, APIException {
	    return all(params, null);
	  }

	  public CustomerSubscriptionCollection all(Map<String, Object> params,
	      String apiKey) throws AuthenticationException,
	      InvalidRequestException, APIConnectionException, CardException,
	      APIException {
	    String url = String.format("%s%s", Stripe.getApiBase(), this.getURL());
	    return request(RequestMethod.GET, url, params,
	        CustomerSubscriptionCollection.class, apiKey);
	  }

	  public Subscription retrieve(String id)
	      throws AuthenticationException, InvalidRequestException,
	      APIConnectionException, CardException, APIException {
	    return retrieve(id, null);
	  }

	  public Subscription retrieve(String id, String apiKey) throws AuthenticationException,
	      InvalidRequestException, APIConnectionException, CardException,
	      APIException {
	    String url = String.format("%s%s/%s", Stripe.getApiBase(), this.getURL(), id);
	    return request(RequestMethod.GET, url, null,
	        Subscription.class, apiKey);
	  }

	  public CustomerSubscriptionCollection create(Map<String, Object> params)
	      throws AuthenticationException, InvalidRequestException,
	      APIConnectionException, CardException, APIException {
	    return create(params, null);
	  }

	  public CustomerSubscriptionCollection create(Map<String, Object> params,
	      String apiKey) throws AuthenticationException,
	      InvalidRequestException, APIConnectionException, CardException,
	      APIException {
	    String url = String.format("%s%s", Stripe.getApiBase(), this.getURL());
	    return request(RequestMethod.POST, url, params,
	        CustomerSubscriptionCollection.class, apiKey);
	  }
}

==> stripe-java-1.15.0-sources.jar: com/stripe/model/CustomerSubscriptionCollection.java <==
package com.stripe.model;

import java.util.Map;

import com.stripe.Stripe;
import com.stripe.exception.APIConnectionException;
import com.stripe.exception.APIException;
import com.stripe.exception.AuthenticationException;
import com.stripe.exception.CardException;
import com.stripe.exception.InvalidRequestException;

public class CustomerSubscriptionCollection extends StripeColllectionAPIResource<Subscription> {
	  public CustomerSubscriptionCollection all(Map<String, Object> params)
	      throws AuthenticationException, InvalidRequestException,
	      APIConnectionException, CardException, APIException {
	    return all(params, null);
	  }

	  public CustomerSubscriptionCollection all(Map<String, Object> params,
	      String apiKey) throws AuthenticationException,
	      InvalidRequestException, APIConnectionException, CardException,
	      APIException {
	    String url = String.format("%s%s", Stripe.getApiBase(), this.getURL());
	    return request(RequestMethod.GET, url, params,
	        CustomerSubscriptionCollection.class, apiKey);
	  }

	  public Subscription retrieve(String id)
	      throws AuthenticationException, InvalidRequestException,
	      APIConnectionException, CardException, APIException {
	    return retrieve(id, null);
	  }

	  public Subscription retrieve(String id, String apiKey) throws AuthenticationException,
	      InvalidRequestException, APIConnectionException, CardException,
	      APIException {
	    String url = String.format("%s%s/%s", Stripe.getApiBase(), this.getURL(), id);
	    return request(RequestMethod.GET, url, null,
	        Subscription.class, apiKey);
	  }

	  public Subscription create(Map<String, Object> params)
	      throws AuthenticationException, InvalidRequestException,
	      APIConnectionException, CardException, APIException {
	    return create(params, null);
	  }

	  public Subscription create(Map<String, Object> params,
	      String apiKey) throws AuthenticationException,
	      InvalidRequestException, APIConnectionException, CardException,
	      APIException {
	    String url = String.format("%s%s", Stripe.getApiBase(), this.getURL());
	    return request(RequestMethod.POST, url, params,
	        Subscription.class, apiKey);
	  }
}
